@@ -14,9 +14,9 @@
 ;; Homepage: https://www.github.com/clojure-emacs/cider
 ;; Keywords: languages, clojure, cider
 ;;
-;; Version: 1.20.0-snapshot
+;; Version: 1.21.0-snapshot
 ;; Package-Requires: (
-;;     (emacs "27")
+;;     (emacs "28")
 ;;     (clojure-mode "5.19")
 ;;     (parseedn "1.2.1")
 ;;     (queue "0.2")
@@ -47,8 +47,8 @@
 
 ;;; Installation:
 
-;; CIDER is available as a package in melpa.org and stable.melpa.org.  First, make sure you've
-;; enabled one of the repositories in your Emacs config:
+;; CIDER is available as a package in melpa.org and stable.melpa.org.  First,
+;; make sure you've enabled one of the repositories in your Emacs config:
 
 ;; (add-to-list 'package-archives
 ;;              '("melpa" . "https://melpa.org/packages/"))
@@ -103,10 +103,10 @@
 (require 'sesman)
 (require 'package)
 
-(defconst cider-version "1.20.0-snapshot"
+(defconst cider-version "1.21.0-snapshot"
   "The current version of CIDER.")
 
-(defconst cider-codename "Skiathos"
+(defconst cider-codename "Lanzarote"
   "Codename used to denote stable releases.")
 
 (defcustom cider-lein-command
@@ -518,7 +518,7 @@ Throws an error if PROJECT-TYPE is unknown."
   "List of dependencies where elements are lists of artifact name and version.")
 (put 'cider-jack-in-dependencies 'risky-local-variable t)
 
-(defcustom cider-injected-nrepl-version "1.5.1"
+(defcustom cider-injected-nrepl-version "1.6.0-alpha1"
   "The version of nREPL injected on jack-in.
 We inject the newest known version of nREPL just in case
 your version of Leiningen is bundling an older one."
